@@ -1,7 +1,15 @@
-# Flake8: noqa
 from .authenticator import Authenticator
-from .config import Config
+from .certs import generate_certs
 from .controller import AuthController
 from .fixture import smtpd
 from .handlers import AuthMessage
 from .smtp import AuthSMTP
+
+__all__ = (
+    "AuthController",
+    "Authenticator",
+    "AuthMessage",
+    "AuthSMTP",
+    "generate_certs",
+    "smtpd",
+)
