@@ -2,7 +2,8 @@ from email.message import EmailMessage
 
 import pytest
 
-from smtpdfix import smtpd  # noqa: F401
+# Register plugions as per pytest documentation preferring this over import.
+pytest_plugins = "smtpdfix"
 
 
 @pytest.fixture
